@@ -420,7 +420,17 @@ message_order const &DataDictionary::getOrderedFields() const {
     return m_orderedFieldsArray;
   }
 
-  return m_orderedFieldsArray = message_order(m_orderedFields.data(), m_orderedFields.size());
+  int *tmp = new int[m_orderedFields.size() + 1];
+  int *i = tmp;
+
+  for (OrderedFields::const_iterator iter = m_orderedFields.begin(); iter != m_orderedFields.end();
+       *(i++) = *(iter++)) {}
+  *i = 0;
+
+  m_orderedFieldsArray = message_order(tmp);
+  delete[] tmp;
+
+  return m_orderedFieldsArray;
 }
 
 message_order const &DataDictionary::getHeaderOrderedFields() const EXCEPT(ConfigError) {
@@ -432,7 +442,17 @@ message_order const &DataDictionary::getHeaderOrderedFields() const EXCEPT(Confi
     throw ConfigError("<Header> does not have a stored message order");
   }
 
-  return m_headerOrder = message_order(m_headerOrderedFields.data(), m_headerOrderedFields.size());
+  int *tmp = new int[m_headerOrderedFields.size() + 1];
+  int *i = tmp;
+
+  for (OrderedFields::const_iterator iter = m_headerOrderedFields.begin(); iter != m_headerOrderedFields.end();
+       *(i++) = *(iter++)) {}
+  *i = 0;
+
+  m_headerOrder = message_order(tmp);
+  delete[] tmp;
+
+  return m_headerOrder;
 }
 
 message_order const &DataDictionary::getTrailerOrderedFields() const EXCEPT(ConfigError) {
@@ -444,7 +464,17 @@ message_order const &DataDictionary::getTrailerOrderedFields() const EXCEPT(Conf
     throw ConfigError("<Trailer> does not have a stored message order");
   }
 
-  return m_trailerOrder = message_order(m_trailerOrderedFields.data(), m_trailerOrderedFields.size());
+  int *tmp = new int[m_trailerOrderedFields.size() + 1];
+  int *i = tmp;
+
+  for (OrderedFields::const_iterator iter = m_trailerOrderedFields.begin(); iter != m_trailerOrderedFields.end();
+       *(i++) = *(iter++)) {}
+  *i = 0;
+
+  m_trailerOrder = message_order(tmp);
+  delete[] tmp;
+
+  return m_trailerOrder;
 }
 
 const message_order &DataDictionary::getMessageOrderedFields(const std::string &msgType) const EXCEPT(ConfigError) {
